# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseWorkspaceMember(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'email': 'str',
        'id': 'int',
        'is_email_verified': 'bool',
        'last_login': 'datetime',
        'name': 'str',
        'permission': 'str',
        'status': 'str',
        'updated_dt': 'datetime',
        'username': 'str'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'email': 'email',
        'id': 'id',
        'is_email_verified': 'is_email_verified',
        'last_login': 'last_login',
        'name': 'name',
        'permission': 'permission',
        'status': 'status',
        'updated_dt': 'updated_dt',
        'username': 'username'
    }

    def __init__(self, created_dt=None, email=None, id=None, is_email_verified=None, last_login=None, name=None, permission=None, status=None, updated_dt=None, username=None, local_vars_configuration=None):  # noqa: E501
        """ResponseWorkspaceMember - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._email = None
        self._id = None
        self._is_email_verified = None
        self._last_login = None
        self._name = None
        self._permission = None
        self._status = None
        self._updated_dt = None
        self._username = None
        self.discriminator = None

        self.created_dt = created_dt
        self.email = email
        self.id = id
        self.is_email_verified = is_email_verified
        self.last_login = last_login
        self.name = name
        self.permission = permission
        self.status = status
        self.updated_dt = updated_dt
        self.username = username

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseWorkspaceMember.  # noqa: E501


        :return: The created_dt of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseWorkspaceMember.


        :param created_dt: The created_dt of this ResponseWorkspaceMember.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def email(self):
        """Gets the email of this ResponseWorkspaceMember.  # noqa: E501


        :return: The email of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ResponseWorkspaceMember.


        :param email: The email of this ResponseWorkspaceMember.  # noqa: E501
        :type email: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def id(self):
        """Gets the id of this ResponseWorkspaceMember.  # noqa: E501


        :return: The id of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseWorkspaceMember.


        :param id: The id of this ResponseWorkspaceMember.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_email_verified(self):
        """Gets the is_email_verified of this ResponseWorkspaceMember.  # noqa: E501


        :return: The is_email_verified of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: bool
        """
        return self._is_email_verified

    @is_email_verified.setter
    def is_email_verified(self, is_email_verified):
        """Sets the is_email_verified of this ResponseWorkspaceMember.


        :param is_email_verified: The is_email_verified of this ResponseWorkspaceMember.  # noqa: E501
        :type is_email_verified: bool
        """
        if self.local_vars_configuration.client_side_validation and is_email_verified is None:  # noqa: E501
            raise ValueError("Invalid value for `is_email_verified`, must not be `None`")  # noqa: E501

        self._is_email_verified = is_email_verified

    @property
    def last_login(self):
        """Gets the last_login of this ResponseWorkspaceMember.  # noqa: E501


        :return: The last_login of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: datetime
        """
        return self._last_login

    @last_login.setter
    def last_login(self, last_login):
        """Sets the last_login of this ResponseWorkspaceMember.


        :param last_login: The last_login of this ResponseWorkspaceMember.  # noqa: E501
        :type last_login: datetime
        """

        self._last_login = last_login

    @property
    def name(self):
        """Gets the name of this ResponseWorkspaceMember.  # noqa: E501


        :return: The name of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResponseWorkspaceMember.


        :param name: The name of this ResponseWorkspaceMember.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def permission(self):
        """Gets the permission of this ResponseWorkspaceMember.  # noqa: E501


        :return: The permission of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: str
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        """Sets the permission of this ResponseWorkspaceMember.


        :param permission: The permission of this ResponseWorkspaceMember.  # noqa: E501
        :type permission: str
        """
        if self.local_vars_configuration.client_side_validation and permission is None:  # noqa: E501
            raise ValueError("Invalid value for `permission`, must not be `None`")  # noqa: E501

        self._permission = permission

    @property
    def status(self):
        """Gets the status of this ResponseWorkspaceMember.  # noqa: E501


        :return: The status of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseWorkspaceMember.


        :param status: The status of this ResponseWorkspaceMember.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def updated_dt(self):
        """Gets the updated_dt of this ResponseWorkspaceMember.  # noqa: E501


        :return: The updated_dt of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this ResponseWorkspaceMember.


        :param updated_dt: The updated_dt of this ResponseWorkspaceMember.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def username(self):
        """Gets the username of this ResponseWorkspaceMember.  # noqa: E501


        :return: The username of this ResponseWorkspaceMember.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this ResponseWorkspaceMember.


        :param username: The username of this ResponseWorkspaceMember.  # noqa: E501
        :type username: str
        """
        if self.local_vars_configuration.client_side_validation and username is None:  # noqa: E501
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWorkspaceMember):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseWorkspaceMember):
            return True

        return self.to_dict() != other.to_dict()
